## Reflection Llama-3.1 70B

Model created by [Matt Shumer](https://www.linkedin.com/in/mattshumer/) which  *is trained with a new technique called Reflection-Tuning that teaches a LLM to detect mistakes in its reasoning and correct course. The model was trained on synthetic data."*

See also: 

- UPDATE: Interesting the Reflection 70b seems to be not quite what it claims [Promptfondler drama: Shumer’s ‘no-hallucination’ Reflection 70B AI turns out to be two other models in a trenchcoat](https://pivot-to-ai.com/2024/09/09/promptfondler-drama-shumers-no-hallucination-reflection-70b-turns-out-to-be-two-other-models-in-a-trenchcoat/)

- LinkedIn: [Matt's post announcing this model](https://www.linkedin.com/posts/mattshumer_im-excited-to-announce-reflection-70b-the-activity-7237801794293174272-kvIm/)
- Medium [Reflection 70B: Enhancing Open-Source AI with Self-Correcting Abilities ](https://medium.com/@LakshmiNarayana_U/reflection-70b-enhancing-open-source-ai-with-self-correcting-abilities-7b09896cc80b)
- You Tube [New LLM DESTROYS Every Other Model with "Self Healing" (Open Source)](https://www.youtube.com/watch?v=FPJ8ED1YhxY&t=2s)
- YouTube [Live Chat with Matt Shumer about Reflection 70b!](https://www.youtube.com/watch?v=5_m-kN64Exc)
- Reddit: [Reflection 70B: Hype?](https://www.reddit.com/r/LocalLLaMA/comments/1fanrr4/reflection_70b_hype/)
- Hugging face [Model weights](https://huggingface.co/mattshumer/Reflection-Llama-3.1-70B)


These models are currently available via **[Open Router](https://openrouter.ai/)** in two versions (a paid and a free version)

----
### Free version
 [mattshumer/reflection-70b:free](https://openrouter.ai/models/mattshumer/reflection-70b:free) | Updated Sep 6
131,072 context | $0/M input tokens | $0/M output tokens


        {{chatbot   name          = "Reflection Llama-3.1 70B (Free)" 
                    platform           = "Open Router (Free)"
                    provider           = "Matt Shumer"
                    model              = "mattshumer/reflection-70b:free"
        }}


----
### Paid version
 [mattshumer/reflection-70b](https://openrouter.ai/models/mattshumer/reflection-70b)  | Updated Sep 6 | 131,072 context | $0.35/M input tokens | $0.4/M output tokens

        {{chatbot   name          = "Reflection Llama-3.1 70B )" 
                    platform           = "Open Router (Free)"
                    provider           = "Matt Shumer"
                    model              = "mattshumer/reflection-70b"
        }}


<script type="module" src="/web_components/js/chat-bots/Chatbot_OpenAI.mjs"></script>
<script src="/assets/plugins/marked/marked.min.js"></script>
